////////////////////////////////////////////////////////////////////////
/*! \file   FrameBufferObject.h
 *  \brief  OpenGL's Frame Buffer Object.
 *  \author Jean-Dominique Gascuel
 *  \copyright ARTIS, Grenoble Universities, 2008.
 *
 * \sa Scene, Shader.
 */
////////////////////////////////////////////////////////////////////////
// $Id: FrameBufferObject.h,v 1.6 2008/02/20 11:49:45 gascuel Exp $
// File History:
// [jDG 2007/03/15] : Creation.

#ifndef FRAME_BUFFER_OBJECT_H
#define FRAME_BUFFER_OBJECT_H

class QImage;

/*! \brief
 */
class FrameBufferObject
{
protected:
    unsigned int    _id;            //!< OpenGL fbo id.
    unsigned int    _rbId;          //!< renderbuffer id, if needed.
    unsigned int    _zId;           //!< renderbuffer id for the depth component, if needed.

public:
    //! \brief Initialise a new frame buffer object.
    FrameBufferObject();

    //! \brief Cleanup and release a frame buffer object.
    virtual ~FrameBufferObject();
    
    /// \brief Was bindDepthTexture() called ?
    virtual bool bound() const { return _id != 0; }

    /*! \brief Attach a FBO to a Qt RGBA image (4x8bits).
     * \code
     *      QImage img(512, 512, 32);
     *      FrameBufferObject fbo;
     *      if( ! fbo.bindColorImage(img) )
     *          return;     // Unsupported feature !
     *      scene.render();
     *      if( ! fbo.finish(img) )
     *          return;     // Something went wrong.
     *      img.save("snapshot.jpg");
     * \endcode
     */
    bool bindColorImage(int width, int height, bool depth = true);

    //! Stop render redirection, and wait for the image to safely by
    //! in the image.
    virtual bool finish(QImage& img) const;
};

#endif // FRAME_BUFFER_OBJECT_H
