////////////////////////////////////////////////////////////////////////
/*! \file   HemiCube.h
 *  \brief  Hemicube for an lighting rendering.
 *  \author Jean-Dominique Gascuel
 *  \copyright ARTIS, Grenoble Universities, 2008.
 *
 * \sa Scene, Shader, FrameBufferObject, EnvironmentMap.
 */
////////////////////////////////////////////////////////////////////////
// $Id: HemiCube.h,v 1.5 2008/02/20 11:49:45 gascuel Exp $
// File History:
// [jDG 2007/12/07] : Creation.

#include "EnvironmentMap.h"

class HemiCube : public EnvironmentMap
{
public:
    HemiCube(Mode, const Vec3f& eye, int size, float radius);
    virtual ~HemiCube();

    //! Don't draw hemicubes...
    virtual bool enable(int, const Shader*) const;
    virtual void disable(int, const Shader*) const;

    //! Return 1 or 5 faces of the hemicube in a single image.
    virtual bool getImage(QImage& image) const;

protected:
    virtual int faces();            //!< Number of faces to render (hemicube=5, sphere=1)
    virtual void createTexture();   //!< Create a 5 faces cubemap, of a simle tex2D.
};
