////////////////////////////////////////////////////////////////////////
/*! \file   OcclusionQuery.cpp
 *  \brief  Using OpenGL Occlusion Query to count fragment drawn.
 *  \author Jean-Dominique Gascuel
 *  \copyright ARTIS, Grenoble Universities, 2008.
 *
 * \sa Shader.
 */
////////////////////////////////////////////////////////////////////////
// $Id: OcclusionQuery.cpp,v 1.5 2008/02/20 11:49:45 gascuel Exp $
// File History:
// [jDG 2007/10/20] : Creation.

#include "OcclusionQuery.h"

#include <GL/glew.h>
#include <qglobal.h>
#include "Utilities.h"

////////////////////////////////////////////////////////////////////////

OcclusionQuery::OcclusionQuery(int target)
{
    if( GLEW_ARB_occlusion_query )
    {
        _target = (target < 0) ? GL_SAMPLES_PASSED : target;
        glGenQueriesARB(1, &_id);
        CHECK_GL_ERROR("Generate occlusion query");

        int bits = 0;
        glGetIntegerv(GL_QUERY_COUNTER_BITS_ARB, &bits);
        Q_ASSERT( bits == 32 );
    }
    else
        _target = _id = 0;
}

////////////////////////////////////////////////////////////////////////

OcclusionQuery::~OcclusionQuery()
{
    if( GLEW_ARB_occlusion_query )
        glDeleteQueriesARB(1, &_id);
}


////////////////////////////////////////////////////////////////////////

void OcclusionQuery::start()
{
    glBeginQuery( _target, _id);
    CHECK_GL_ERROR("glBeginQuery");
}

////////////////////////////////////////////////////////////////////////

void OcclusionQuery::stop()
{
    glEndQuery( _target );
    CHECK_GL_ERROR("glEndQuery");
}

////////////////////////////////////////////////////////////////////////

bool OcclusionQuery::isReady()
{
    GLuint ready;

    glGetQueryObjectuiv(_id, GL_QUERY_RESULT_AVAILABLE, &ready);
    CHECK_GL_ERROR("glGetQueryObject RESULT_AVAILABLE");

    return ready == GL_TRUE;
}

////////////////////////////////////////////////////////////////////////

unsigned long OcclusionQuery::count()
{
    GLuint samples;

    glGetQueryObjectuiv(_id, GL_QUERY_RESULT, &samples);
    CHECK_GL_ERROR("glGetQueryObject RESULT");

    return samples;
}
