%{
////////////////////////////////////////////////////////////////////////
/*! \file   Scene_vrml.l
 *  \brief  Parser for VRML tokens.
 *  \author Jean-Dominique Gascuel
 *  \copyright ARTIS, Grenoble Universities, 2008.
 */
////////////////////////////////////////////////////////////////////////
// $Id: Scene_vrml.l,v 1.8 2008/02/20 11:49:45 gascuel Exp $

#include <QString>
#include <QProgressDialog>
#include "Scene_vrml_yacc.h"

#define YY_NEVER_INTERACTIVE 1
#define YY_NO_UNISTD_H 1

int Scene_vrml_lineno = 0;
int Scene_vrml_version = 0;
extern const char* Scene_vrml_file;
extern QProgressDialog *progress;
%}

%%
TRUE|True|true      return VRML_TRUE;
FALSE|False|false   return VRML_FALSE;

DEF             return VRML_DEF;
USE             return VRML_USE;

Separator       return VRML_SEPARATOR;
Group           return VRML_GROUP;
Transform       return VRML_TRANSFORM;
    translation         return VRML_TRANSLATION;
    rotation            return VRML_ROTATION;
    scaleFactor         return VRML_SCALE;          // VRML1
    scale               return VRML_SCALE;
    center              return VRML_CENTER;
    scaleOrientation    return VRML_SCALEORIENTATION;
    children            return VRML_CHILDREN;

Shape           return VRML_SHAPE;
    appearance          return VRML_APPEARANCE;
    geometry            return VRML_GEOMETRY;
    texture             return VRML_TEXTURE;

Appearance      return VRML_APPEARANCE;
    material            return VRML_MATERIAL;

Material        return VRML_MATERIAL;
    ambientIntensity    return VRML_AMBIENTINTENSITY;
    diffuseColor        return VRML_DIFFUSECOLOR;
    specularColor       return VRML_SPECULARCOLOR;
    shininess           return VRML_SHININESS;
    transparency        return VRML_TRANSPARENCY;

NormalBinding   return VRML_NORMALBINDING;
    value               return VRML_VALUE;
    PER_VERTEX_INDEXED  return VRML_PER_VERTEX_INDEXED;

Normal          return VRML_NORMAL;
    vector              return VRML_VECTOR;

Coordinate      return VRML_COORDINATE;
Coordinate3     return VRML_COORDINATE;
    point               return VRML_POINT;
TextureCoordinate  return VRML_TEXCOORD;
TextureCoordinate2 return VRML_TEXCOORD;

Texture2        return VRML_TEXTURE;
    image               return VRML_IMAGE;
ImageTexture    return VRML_TEXTURE;
    url                 return VRML_URL;

IndexedFaceSet  return VRML_IFS;
    ccw                 return VRML_CCW;                // VRML2
    solid               return VRML_SOLID;              // VRML2
    convex              return VRML_CONVEX;             // VRML2
    coord               return VRML_COORD;              // VRML2
    coordIndex          return VRML_COORDINDEX;
    normalPerVertex     return VRML_NORMALPERVERTEX;    // VRML2
    normal              return VRML_NORMAL;             // VRML2
    normalIndex         return VRML_NORMALINDEX;
    texCoord            return VRML_TEXCOORD;           // VRML2
    texCoordIndex       return VRML_TEXCOORDINDEX;      // VRML2
    textureCoordIndex   return VRML_TEXCOORDINDEX;      // VRML1

Box             return VRML_BOX;
    size                return VRML_SIZE;

Sphere          return VRML_SPHERE;
    radius              return VRML_RADIUS;

[a-zA-Z][a-zA-Z0-9_-]*  return VRML_NAME;

["][^"]+["]     return VRML_STRING;

-?[0-9]+            return VRML_VALUE;
0x[0-9a-fA-F]+      return VRML_VALUE;
-?[0-9]*[.][0-9]+([eE][+-]?[0-9]+)?    return VRML_VALUE;

[{}\[\]]        return yytext[0];
[#].*           {
                    char mode[10] = "";
                    float version=0.0;
                    if( sscanf(yytext, "#VRML V%f %10s", &version, mode)==2 )
                    {
                        if( version < 1.0f || version > 2.0f )
                            qWarning( "Only VRML v1.0 or VRML97 files are supported" );
                        if( mode != QString("ascii") && mode != QString("utf8") )
                            qWarning( "Only ascii VRML files are supported");
                        
                        qWarning( "Reading 'VRML v%3.1f %s' file", version, mode);
                        Scene_vrml_version = int(version);
                        return VRML_HEADER;
                    }
                }
[,\ \t]         ;
[\n]            {
                    ++Scene_vrml_lineno;
                    if( (Scene_vrml_lineno&100) == 0 )
                        progress->setValue(ftell(yyin));
                }
%%

int yywrap()
{
    return 1;
}