# $Id: TBender.pri,v 1.19 2007/12/09 01:24:55 gascuel Exp $
#-----------------------------------------------------------------------------
# Make sure we do have a Qt 4.x.x version at hand :
#-----------------------------------------------------------------------------
isEmpty(QT) : error(Qt4 is mandatory for this application)
!exists( $$(QTDIR)/include/QtCore ): error(QTDIR not set to Qt4 directory)

#-----------------------------------------------------------------------------

TARGET   = TBender
TEMPLATE = app
CONFIG   *= console qt warn_on std-zlib
CONFIG   *= nv4x
QT       *= opengl
QT       -= xml

#-----------------------------------------------------------------------------
# Add access to external libraries...

!include( glew.pri )      : error( Unable to get GLEW )
!include( qglviewer.pri ) : error( Unable to get QGLViewer )

#-----------------------------------------------------------------------------

HEADERS += \
    Math/Math.h                     \
    Math/Vec4f.h                    \
    Math/Vec3f.h                    \
    Math/Vec2f.h                    \
    Math/Quaternion.h               \
    Math/Matrix4.h                  \
    Utilities.h                     \
    BasicGLViewer.h                 \
    Shader.h                        \
    Feedback.h                      \
    FrameBufferObject.h             \
    OcclusionQuery.h                \
    ShadowMap.h                     \
    EnvironmentMap.h                \
    HemiCube.h                      \
    GlossyMap.h                     \
    Scene.h

SOURCES += \
    Math/Math.cpp                   \
    Utilities.cpp                   \
    main.cpp                        \
    BasicGLViewer.cpp               \
    Scene_obj.cpp                   \
    Shader.cpp                      \
    Feedback.cpp                    \
    FrameBufferObject.cpp           \
    OcclusionQuery.cpp              \
    ShadowMap.cpp                   \
    EnvironmentMap.cpp              \
    HemiCube.cpp                    \
    GlossyMap.cpp                   \
    Scene.cpp

DEFINES *= \
    _CRT_SECURE_NO_DEPRECATE=1

#-----------------------------------------------------------------------------
# Some cleanups

win32 {
    debug   : OBJECTS_DIR = Debug/Obj/
    release : OBJECTS_DIR = Release/Obj/
    MOC_DIR = Generated/
     UI_DIR = Generated/
     
    win32-msvc2005 {
        DEFINES += _CRT_SECURE_NO_DEPRECATE=1

        QMAKE_CXXFLAGS = -MD -fp:fast -arch:SSE2 -GR -FC
        QMAKE_CXXFLAGS_RELEASE = -MD  -Ox -Ot -Oi -Oy -Ob2 -GS-
        QMAKE_CXXFLAGS_DEBUG   = -MDd -Od -Zi -RTCsu -FR$${OBJECTS_DIR} -Fd$${OBJECTS_DIR} -GS
        QMAKE_CXXFLAGS_WARN_ON = -W3 
    }
    # CONFIG *= $$(PROCESSOR_ARCHITECTURE)
    # AMD64 {
    #     QMAKE_LIBDIR *= "$$(VCINSTALLDIR)/ATLMFC/lib/AMD64"
    #     QMAKE_LIBDIR *= "$$(VCINSTALLDIR)/lib/AMD64"
    #     QMAKE_LIBDIR *= "$$(VCINSTALLDIR)/PlatformSDK/lib/AMD64"
    # }
}
unix {
    debug   : OBJECTS_DIR = .debug/Obj/
    release : OBJECTS_DIR = .release/Obj/
    MOC_DIR = .generated/
     UI_DIR = .generated/
}

#-----------------------------------------------------------------------------

win32 {
    # Suppose Unix Utils is in the path...
    exists( "C:/Program Files/UnixUtils/bison.exe" ):               YACC = bison
    exists( "C:/Program Files/UnxUtils/usr/local/wbin/bison.exe" ): YACC = set BISON_SIMPLE=C:/Program Files/UnxUtils/usr/local/share/bison.simple && bison

    exists( "C:/Program Files/UnixUtils/flex.exe" ):               FLEX = flex
    exists( "C:/Program Files/UnxUtils/usr/local/wbin/flex.exe" ): FLEX = flex
}

unix {
    YACC = bison
    FLEX = flex
}

!isEmpty(YACC) {
    message(Using yacc: $$YACC)
    QMAKE_YACC   = $$YACC --yacc --no-lines -v
    YACCSOURCES += Scene_vrml.y
} else {
    HEADERS += Scene_vrml_yacc.h
    SOURCES += Scene_vrml_yacc.cpp
}

!isEmpty(FLEX) {
    message(Using lex: $$FLEX)
    QMAKE_LEX   = $$FLEX -L
    LEXSOURCES += Scene_vrml.l
} else {
    SOURCES += Scene_vrml_lex.cpp
}


#-----------------------------------------------------------------------------
# Just to have Cg sources in Visual C++ menu :
win32-msvc*: SHADERS_SOURCES = $$VERTEX_SOURCES $$GEOMETRY_SOURCES $$FRAGMENT_SOURCES $$GLSL_SOURCES

#-----------------------------------------------------------------------------

std-zlib {
    isEmpty( ZLIB_INC ) {
        exists( $$(QTDIR)/src/3rdparty/zlib/zlib.h ): ZLIB_INC = $$(QTDIR)/src/3rdparty/zlib
        exists( /usr/include/zlib.h ) {
            ZLIB_INC = /usr/include
            ZLIB_LIB = -lz
        }
    }

    ! exists( $${ZLIB_INC}/zlib.h ) : message( Unable to find zlib. Redo qmake with ZLIB_INC=... ZLIB_LIB=... options )
    
    INCLUDEPATH *= $${ZLIB_INC}
    LIBS *= $${ZLIB_LIB}
}
