//////////////////////////////////////////////////////////////////////////////
/*! \file   Utilities.cpp
 *  \brief  Various functions for TBender
 *  \author Jean-Dominique Gascuel
 *  \copyright ARTIS, Grenoble Universities, 2008.
 */
//////////////////////////////////////////////////////////////////////////////
// $Id: Utilities.cpp,v 1.9 2008/02/20 11:49:45 gascuel Exp $
// File History:
// [jDG 2007/04/13] : Creation.

#include "Utilities.h"

#include <GL/glew.h>
#ifdef WIN32
#   include <windows.h>
#endif
#include <QApplication>
#include <QTime>

//////////////////////////////////////////////////////////////////////////////

double
TBender::time()
{
#ifdef WIN32
    // ---- Autocalibrate frequency with a 100ms sleep -----------------------
    static double frequency = 0.0;  // NOTE: float is not enough to get more than ms
    if( frequency == 0.0 )
    {
        long long ifreq = 0ll;
        QueryPerformanceFrequency((PLARGE_INTEGER)&ifreq);
        frequency = (double)ifreq;
    }

    long long count = 0ll;
    QueryPerformanceCounter((PLARGE_INTEGER)&count);
    return count / frequency;

#else
    const QTime &now = QTime::currentTime();
    return now.hour()   * 3600.0f
         + now.minute() * 60.0f
         + now.second()
         + now.msec()   * 0.001f;
#endif
}

//////////////////////////////////////////////////////////////////////////////

QString
TBender::timeCString(double t)
{
    QString r;
    if( t < 0.000001 )
        r.sprintf("%6.2f nsec", t * 1000000000.0f);
    else if( t < 0.001 )
        r.sprintf("%6.2f musec", t * 1000000.0f);
    else if( t < 1.0f )
        r.sprintf("%6.2f msec", t * 1000.0f);
    else if( t < 100.0f )
        r.sprintf("%6.2f sec", t);
    else if( t < 3600.0f )
        r.sprintf("%02d:%02d", int(t+0.5f)/60, int(t+0.5f)%60);
    else
        r.sprintf("%02d:%02d:%02d", int(t)/3600, (int(t+0.5)/60)%60, int(t)%60);
    return r;
}

//////////////////////////////////////////////////////////////////////////////

void TBender::checkGLError(const char *file, int line, const char *what)
{
   while( int error = glGetError() )
   {
       const char *errs = (const char *)gluErrorString(error);
       if( ! errs )
       {
           switch( error )
           {
           case GL_INVALID_FRAMEBUFFER_OPERATION_EXT:
               errs = "Invalid Framebuffer Operation";
               break;

           default:
               static char errorNumber[64];
               sprintf(errorNumber, "0x%X", error);
               errs = errorNumber;
               break;
           }
       }

        qWarning("OpenGL ERROR: \"%s\", line %d [%s] %s",
            file, line, 
            errs,
            what ? what : "");
   }
}

