##############################################################################
#
# Cg compilation rules
#
# (c) jD Gascuel / ARTIS / 2006.
# $Id: cg_rules.pri,v 1.9 2006/12/06 22:23:14 gascuel Exp $

win32: isEmpty(CGC)             : CGC         = "\"$$(CG_BIN_PATH)\cgc.exe\""
 unix: isEmpty(CGC)             : CGC         = cgc
isEmpty(CGC_FLAGS)              : CGC_FLAGS   = -strict -entry main
isEmpty(CGC_DIR)                : CGC_DIR     = $${MOC_DIR}
debug: CGC_FLAGS += -debug

win32: INCLUDEPATH *= "$$(CG_INC_PATH)"
win32: LIBS *= "\"$$(CG_LIB_PATH)/cg.lib\""
 unix: LIBS *= /usr/lib/libCg.so

# ---- Standard OpenGL various profiles --------------------------------------

arb {
    message( Compiling Cg for OpenGL ARB profiles )
    isEmpty(CGC_VERTEX_PROFILE)     : CGC_VERTEX_PROFILE   = arbvp1
    isEmpty(CGC_FRAGMENT_PROFILE)   : CGC_FRAGMENT_PROFILE = arbfp1
    CG_DEFINES += OPENGL=1 ARB=1
}

glsl {
    message( Compiling Cg for OpenGL GLSL profiles )
    isEmpty(CGC_VERTEX_PROFILE)     : CGC_VERTEX_PROFILE   = glslv
    isEmpty(CGC_FRAGMENT_PROFILE)   : CGC_FRAGMENT_PROFILE = glslf
    CG_DEFINES += OPENGL=1 GLSL=1
}

# ---- NVidia specific OpenGL profiles ---------------------------------------

nv2x {
    message( *** Compiling Cg for OpenGL Nvidia's NV2x profiles *** )
    # GeForce 3, GeForce 4 Ti, Quadro DCC, etc.
    isEmpty(CGC_VERTEX_PROFILE)     : CGC_VERTEX_PROFILE   = vp20
    isEmpty(CGC_FRAGMENT_PROFILE)   : CGC_FRAGMENT_PROFILE = fp20
    CG_DEFINES += OPENGL=1 NV2X=1
}

nv3x {
    message( *** Compiling Cg 1.3 for OpenGL Nvidia's NV3x profiles *** )
    # GeForce FX, Quadro FX
    isEmpty(CGC_VERTEX_PROFILE)     : CGC_VERTEX_PROFILE   = vp30
    isEmpty(CGC_FRAGMENT_PROFILE)   : CGC_FRAGMENT_PROFILE = fp30
    CG_DEFINES += OPENGL=1 NV3X=1
}

nv4x {
    message( *** Compiling Cg 1.5 for OpenGL Nvidia's NV4x profiles *** )
    # GeForce 6xxx, GeForce 7xxx, NV4x based Quadro's FX
    isEmpty(CGC_VERTEX_PROFILE)     : CGC_VERTEX_PROFILE   = vp40
    isEmpty(CGC_FRAGMENT_PROFILE)   : CGC_FRAGMENT_PROFILE = fp40
    CG_DEFINES += OPENGL=1 NV4X=1
}

g80 {
    message( *** Compiling Cg 1.6 for OpenGL Nvidia's G80 profiles *** )
    # No profile yet !!!
    isEmpty(CGC_VERTEX_PROFILE)     : CGC_VERTEX_PROFILE   = gp4vp
    isEmpty(CGC_GEOMETRY_PROFILE)   : CGC_GEOMETRY_PROFILE = gp4gp
    isEmpty(CGC_FRAGMENT_PROFILE)   : CGC_FRAGMENT_PROFILE = gp4fp
    CG_DEFINES += OPENGL=1 G80=1
}

# ---- Microsoft DirectX various profiles ------------------------------------

dx8 dx8.1 {
    message( Compiling Cg for DirectX 8.1 profiles )
    # Also dx8vs
    isEmpty(CGC_VERTEX_PROFILE)     : CGC_VERTEX_PROFILE   = vs_1_1
    isEmpty(CGC_FRAGMENT_PROFILE)   : CGC_FRAGMENT_PROFILE = ps_1_1
    CG_DEFINES += DIRECTX=1 DX8=1 DX81=1 DX=81
}

dx8.2 {
    message( Compiling Cg for DirectX 8.2 profiles )
    isEmpty(CGC_VERTEX_PROFILE)     : CGC_VERTEX_PROFILE   = vs_1_1
    isEmpty(CGC_FRAGMENT_PROFILE)   : CGC_FRAGMENT_PROFILE = ps_1_2
    CG_DEFINES += DIRECTX=1 DX8=1 DX81=1 DX82=1 DX=82
}

dx8.3 {
    message( Compiling Cg for DirectX 8.3 profiles )
    isEmpty(CGC_VERTEX_PROFILE)     : CGC_VERTEX_PROFILE   = vs_1_1
    isEmpty(CGC_FRAGMENT_PROFILE)   : CGC_FRAGMENT_PROFILE = ps_1_3
    CG_DEFINES += DIRECTX=1 DX8=1 DX81=1 DX82=1 DX83=1 DX=83
}

dx9 {
    message( Compiling Cg 1.3 for DirectX 9 profiles )
    # Also vs_2_0
    # Also dxvs2, dx9ps2, ps_2_0
    isEmpty(CGC_VERTEX_PROFILE)     : CGC_VERTEX_PROFILE   = vs_2_x
    isEmpty(CGC_FRAGMENT_PROFILE)   : CGC_FRAGMENT_PROFILE = ps_2_x
    CG_DEFINES += DIRECTX=1 DX9=1 DX=90
}

dx9c {
    message( Compiling Cg 1.5 for DirectX 9c profiles )
    # Also vs_2_x
    # Also dxvs2, dx9ps2, ps_2_x
    isEmpty(CGC_VERTEX_PROFILE)     : CGC_VERTEX_PROFILE   = vs_3_0
    isEmpty(CGC_FRAGMENT_PROFILE)   : CGC_FRAGMENT_PROFILE = ps_3_0
    CG_DEFINES += DIRECTX=1 DX9=1 DX9c=1 DX=93
}

dx10 {
    message( Compiling Cg for DirectX 10 profiles )
    # Not yet : just a guess !
    isEmpty(CGC_VERTEX_PROFILE)     : CGC_VERTEX_PROFILE   = ps_4_0
    isEmpty(CGC_GEOMETRY_PROFILE)   : CGC_GEOMETRY_PROFILE = gs_4_0
    isEmpty(CGC_FRAGMENT_PROFILE)   : CGC_FRAGMENT_PROFILE = vs_4_0
    CG_DEFINES += DIRECTX=1 DX10=1
}

# ---- Use the Cg runtime library accordingly to DX/GL profile ---------------

DEFINES *= $${CG_DEFINES}

contains(CG_DEFINES, OPENGL=1) {
    message(Compile Cg / OpenGL interface )
    win32: LIBS *= "\"$$(CG_LIB_PATH)/cgGL.lib\""
     unix: LIBS *= /usr/lib/libCgGL.so
} else {
    unix: error(No DirectX under linux...)

    message(Compile Cg / DirectX interface )
    contains(CG_DEFINES, DX8=1) : LIBS *= "$$(CG_LIB_PATH)/cgD3D8.lib"
    contains(CG_DEFINES, DX9=1) : LIBS *= "$$(CG_LIB_PATH)/cgD3D9.lib"
}

# ---- Default all to generic profile ----------------------------------------

!isEmpty(CGC_VERTEX_PROFILE)   : message(Cg vertex   profile is $${CGC_VERTEX_PROFILE})
!isEmpty(CGC_GEOMETRY_PROFILE) : message(Cg geometry profile is $${CGC_GEOMETRY_PROFILE})
!isEmpty(CGC_FRAGMENT_PROFILE) : message(Cg fragment profile is $${CGC_FRAGMENT_PROFILE})

isEmpty(CGC_VERTEX_PROFILE)  : CGC_VERTEX_PROFILE   = generic
isEmpty(CGC_GEOMETRY_PROFILE): CGC_GEOMETRY_PROFILE = generic
isEmpty(CGC_FRAGMENT_PROFILE): CGC_FRAGMENT_PROFILE = generic

# ---- Then the compile rules ------------------------------------------------

# Unused : Cg VertexShader.CONFIG    = combined
# Unused : Cg VertexShader.vars      = CGC CGC_FLAGS (unix only ?)

Cg VertexShader.name      = Cg vertex compiler
Cg VertexShader.output    = $${CGC_DIR}/${QMAKE_FILE_BASE}_$${CGC_VERTEX_PROFILE}.vs
Cg VertexShader.commands  = "$${CGC}" -profile $${CGC_VERTEX_PROFILE} $${CGC_FLAGS} $$join(CG_DEFINES, " -D", "-D") ${QMAKE_FILE_NAME} -o ${QMAKE_FILE_OUT}
Cg VertexShader.input     = VERTEX_SOURCES
QMAKE_EXTRA_COMPILERS += "Cg VertexShader"

Cg GeometryShader.name     = Cg geometry compiler
Cg GeometryShader.output   = $${CGC_DIR}/${QMAKE_FILE_BASE}_$${CGC_GEOMETRY_PROFILE}.gs
Cg GeometryShader.commands = "$${CGC}" -profile $${CGC_GEOMETRY_PROFILE} $${CGC_FLAGS} $$join(CG_DEFINES, " -D", "-D") ${QMAKE_FILE_NAME} -o ${QMAKE_FILE_OUT}
Cg GeometryShader.input = GEOMETRY_SOURCES
QMAKE_EXTRA_COMPILERS += "Cg GeometryShader"

Cg FragmentShader.name  = Cg fragment compiler
Cg FragmentShader.output  = $${CGC_DIR}/${QMAKE_FILE_BASE}_$${CGC_FRAGMENT_PROFILE}.ps
Cg FragmentShader.commands = "$${CGC}" -profile $${CGC_FRAGMENT_PROFILE} $${CGC_FLAGS} $$join(CG_DEFINES, " -D", "-D") ${QMAKE_FILE_NAME} -o ${QMAKE_FILE_OUT}
Cg FragmentShader.input = FRAGMENT_SOURCES
QMAKE_EXTRA_COMPILERS += "Cg FragmentShader"

# ---- Make sure the sources are in the MSVC project file, and saved by "make dist"
#
Shaders.output   = ${QMAKE_FILE_NAME}
Shaders.input    = SHADERS_SOURCES
QMAKE_EXTRA_COMPILERS += Shaders
DIST += ${SHADERS_SOURCES}
