##############################################################################
#
# GLSL compilation rules
#
# (c) jD Gascuel / ARTIS / 2007.
# $Id: glsl_rules.pri,v 1.1 2007/04/06 12:56:22 gascuel Exp $

# This is just a syntax checker. No ARB shader is produced...
isEmpty(GLSLC)    : GLSLC    = glslc.exe
isEmpty(GLSL_DIR) : GLSL_DIR = Shaders
!exists( $$GLSL_DIR ) : !system( mkdir "$$GLSL_DIR" ): error(Cannot creates dir $$GLSL_DIR )

# ---- Analyse list of provided shaders --------------------------------------
#
# Note: This file should be included *AFTER* defining GLSL_SOURCES variable !

# Auto-detect shader types from file name :
GLSL_FRAGMENT_SOURCES *= $$find(GLSL_SOURCES, .*_fragment.*) $$find(GLSL_SOURCES, .*[.]fs)
GLSL_GEOMETRY_SOURCES *= $$find(GLSL_SOURCES, .*_geometry.*) $$find(GLSL_SOURCES, .*[.]gs)
GLSL_VERTEX_SOURCES   *= $$find(GLSL_SOURCES, .*_vertex.*)   $$find(GLSL_SOURCES, .*[.]vs)

# Don't create duplicates :
GLSL_SOURCES -= $$GLSL_FRAGMENT_SOURCES $$GLSL_GEOMETRY_SOURCES $$GLSL_VERTEX_SOURCES

# ---- Then fake compile rules -----------------------------------------------

# Unused : GLSL.CONFIG    = combined
# Unused : GLSL.vars      = GLSLC CGC_FLAGS (unix only ?)

GLSL_Fragment_Shaders.name      = "------ GLSL Fragment shader syntax checking:"
GLSL_Fragment_Shaders.output    = $${GLSL_DIR}/${QMAKE_FILE_BASE}.fs
GLSL_Fragment_Shaders.commands = "$${GLSLC}" -o $${GLSL_DIR}/${QMAKE_FILE_BASE}.fs -fragment ${QMAKE_FILE_NAME}
GLSL_Fragment_Shaders.input     = GLSL_FRAGMENT_SOURCES
QMAKE_EXTRA_COMPILERS += "GLSL_Fragment_Shaders"

GLSL_Geometry_Shaders.name      = "------ GLSL Geometry shader syntax checking:"
GLSL_Geometry_Shaders.output    = $${GLSL_DIR}/${QMAKE_FILE_BASE}.gs
GLSL_Geometry_Shaders.commands = "$${GLSLC}" -o $${GLSL_DIR}/${QMAKE_FILE_BASE}.gs -geometry ${QMAKE_FILE_NAME}
GLSL_Geometry_Shaders.input     = GLSL_GEOMETRY_SOURCES
QMAKE_EXTRA_COMPILERS += "GLSL_Geometry_Shaders"

GLSL_Vertex_Shaders.name     = "------ GLSL Vertex shader syntax checking:"
GLSL_Vertex_Shaders.output   = $${GLSL_DIR}/${QMAKE_FILE_BASE}.vs
GLSL_Vertex_Shaders.commands = "$${GLSLC}" -o $${GLSL_DIR}/${QMAKE_FILE_BASE}.vs -vertex ${QMAKE_FILE_NAME}
GLSL_Vertex_Shaders.input    = GLSL_VERTEX_SOURCES
QMAKE_EXTRA_COMPILERS += "GLSL_Vertex_Shaders"

contains(TEMPLATE, vc.*) {
	GLSL_Fragment_Shaders.output = ${QMAKE_FILE_NAME}
	GLSL_Geometry_Shaders.output = ${QMAKE_FILE_NAME}
	GLSL_Vertex_Shaders.output   = ${QMAKE_FILE_NAME}
}

#other shaders : cannot know wether it is a frag/geom.vertex --> no check...
GLSL_Shaders.output    = ${QMAKE_FILE_NAME}
GLSL_Shaders.input     = GLSL_SOURCES
QMAKE_EXTRA_COMPILERS += "GLSL_Shaders"

# ---- Make sure the sources are saved by "make dist" ------------------------
#
DIST += ${GLSL_SOURCES} $${GLSL_FRAGMENT_SOURCES} $${GLSL_GEOMETRY_SOURCES} $${GLSL_VERTEX_SOURCES}
